==> jbpm-springboot-example-0.3.0-sources.jar: org/acme/kogito/RulesE405F32A817FD57B535435BB6FB960B3RuleMethods0.java <==
package org.acme.kogito;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.kie.kogito.examples.demo.Person;
import static org.acme.kogito.RulesE405F32A817FD57B535435BB6FB960B3.*;

public class RulesE405F32A817FD57B535435BB6FB960B3RuleMethods0 {

    /**
     * Rule name: Is adult
     */
    public static org.drools.model.Rule rule_Is_32adult() {
        final org.drools.model.Variable<org.kie.kogito.examples.demo.Person> var_$person = D.declarationOf(org.kie.kogito.examples.demo.Person.class,
                                                                                                           DomainClassesMetadataE405F32A817FD57B535435BB6FB960B3.org_kie_kogito_examples_demo_Person_Metadata_INSTANCE,
                                                                                                           "$person");
        final org.drools.model.BitMask mask_$person = org.drools.model.BitMask.getPatternMask(DomainClassesMetadataE405F32A817FD57B535435BB6FB960B3.org_kie_kogito_examples_demo_Person_Metadata_INSTANCE,
                                                                                              "adult");
        org.drools.model.Rule rule = D.rule("org.acme.kogito",
                                            "Is adult").attribute(Rule.Attribute.RULEFLOW_GROUP,
                                                                  "person")
                                                       .build(D.pattern(var_$person).expr("78043B7D0A1598801B4B437C3CDA7CF8",
                                                                                          (_this) -> org.drools.modelcompiler.util.EvaluationUtil.greaterThanNumbers(_this.getAge(),
                                                                                                                                                                     18),
                                                                                          D.alphaIndexedBy(java.lang.Integer.class,
                                                                                                           org.drools.model.Index.ConstraintType.GREATER_THAN,
                                                                                                           0,
                                                                                                           _this -> _this.getAge(),
                                                                                                           18),
                                                                                          D.reactOn("age")),
                                                              D.on(var_$person).execute((drools, $person) -> {
                                                                  {
                                                                      ($person).setAdult(true);
                                                                      drools.update($person,
                                                                                    mask_$person);
                                                                  }
                                                              }));
        return rule;
    }
}

==> jbpm-springboot-example-0.6.1-sources.jar: org/acme/kogito/RulesE405F32A817FD57B535435BB6FB960B3RuleMethods0.java <==
package org.acme.kogito;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.kie.kogito.examples.demo.Person;
import static org.acme.kogito.RulesE405F32A817FD57B535435BB6FB960B3.*;

public class RulesE405F32A817FD57B535435BB6FB960B3RuleMethods0 {

    /**
     * Rule name: Is adult
     */
    public static org.drools.model.Rule rule_Is_32adult() {
        final org.drools.model.Variable<org.kie.kogito.examples.demo.Person> var_$person = D.declarationOf(org.kie.kogito.examples.demo.Person.class,
                                                                                                           DomainClassesMetadataE405F32A817FD57B535435BB6FB960B3.org_kie_kogito_examples_demo_Person_Metadata_INSTANCE,
                                                                                                           "$person");
        final org.drools.model.BitMask mask_$person = org.drools.model.BitMask.getPatternMask(DomainClassesMetadataE405F32A817FD57B535435BB6FB960B3.org_kie_kogito_examples_demo_Person_Metadata_INSTANCE,
                                                                                              "adult");
        org.drools.model.Rule rule = D.rule("org.acme.kogito",
                                            "Is adult").attribute(Rule.Attribute.RULEFLOW_GROUP,
                                                                  "person")
                                                       .build(D.pattern(var_$person).expr("78043B7D0A1598801B4B437C3CDA7CF8",
                                                                                          (_this) -> org.drools.modelcompiler.util.EvaluationUtil.greaterThanNumbers(_this.getAge(),
                                                                                                                                                                     18),
                                                                                          D.alphaIndexedBy(java.lang.Integer.class,
                                                                                                           org.drools.model.Index.ConstraintType.GREATER_THAN,
                                                                                                           DomainClassesMetadataE405F32A817FD57B535435BB6FB960B3.org_kie_kogito_examples_demo_Person_Metadata_INSTANCE.getPropertyIndex("age"),
                                                                                                           _this -> _this.getAge(),
                                                                                                           18),
                                                                                          D.reactOn("age")),
                                                              D.on(var_$person).execute((drools, $person) -> {
                                                                  {
                                                                      ($person).setAdult(true);
                                                                      drools.update($person,
                                                                                    mask_$person);
                                                                  }
                                                              }));
        return rule;
    }
}
